pub enum RxBufferManagement {
Static_(Static),
Simple(Simple),
// some variants omitted
}Expand description
Parameters for Rx buffer management.
Variants
Static_(Static)
No dynamic management, queue everything. The default algorithm.
Simple(Simple)
Use Little’s Law: Queue size is the product of packet arrival rate and the average time each packet spend in the queue (L = lambda * W).
Implementations
Sourceimpl RxBufferManagement
impl RxBufferManagement
pub fn ordinal(&self) -> u64
pub fn unknown_variant_for_testing() -> Self
pub fn is_unknown(&self) -> bool