pub struct Simple {
pub alpha: f64,
pub delay_budget: i64,
}Fields
alpha: f64This is used to calculate the arrival rate:
Rate_n = alpha * Sample_n + (1 - alpha) * Rate_(n-1)
The bigger this value, the more sensitive it is to the latest sample.
Must be in the range [0, 1].
delay_budget: i64Wait time budget at the driver.
This is equivalent to W in Little’s Law. More practically, this is an upper bound for the average time buffers spend waiting in the queue of the device impl before they are processed by the device interface.
Guidance for driver implementors:
- If your driver uses a interrupt coalescing timeout, then this W should just be that or slightly larger to account for the processing time.
- If your driver does not use moderation, this value can be tuned: a starting point would be to use (bit rate, MTU, Rx depth) to derive a W under maximum pressure. As a reference (1Gbps, 1500, 256) leads to a W of 3.0 ms (256 / (10**9 / 8 / 1500) seconds). It will make little sense to go any bigger than that and you can decrease it and monitor for packet drops. You can compare the value against common interrupt coalescing configurations for reference.